@@ -11,7 +11,6 @@ __metaclass__ = type
 
 DOCUMENTATION = r"""
     name: vmware_host_inventory
-    plugin_type: inventory
     short_description: VMware ESXi hostsystem inventory source
     author:
       - Abhijeet Kasurde (@Akasurde)
@@ -191,7 +190,7 @@ from ansible.errors import AnsibleError
 from ansible.module_utils._text import to_text, to_native
 from ansible.module_utils.common.dict_transformations import camel_dict_to_snake_dict
 from ansible.module_utils.six import text_type
-from ansible_collections.community.vmware.plugins.module_utils.inventory import (
+from ansible_collections.community.vmware.plugins.plugin_utils.inventory import (
     to_nested_dict,
     to_flatten_dict,
 )
@@ -391,13 +390,14 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
 
             host_properties = to_nested_dict(properties)
 
+            # Check if we can add host as per filters
+            host_filters = self.get_option("filters")
+            if not self._can_add_host(host_filters, host_properties, strict=strict):
+                continue
+
             host = self._get_hostname(host_properties, hostnames, strict=strict)
 
-            host_filters = self.get_option("filters")
-
-            if host not in hostvars and self._can_add_host(
-                host_filters, host_properties, strict=strict
-            ):
+            if host not in hostvars:
                 hostvars[host] = host_properties
                 self._populate_host_properties(host_properties, host)
                 self.inventory.set_variable(
